import { select, csv, scaleLinear, max, scaleBand, axisLeft, axisBottom,
       format} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');



const render = data => {
  
  const xValue = d => d.population
  const yValue = d => d.country
  const margin = {bottom:70, top:50, left:200, right:20}
  const innerWidth = width - margin.left - margin.right
  const innerHeight = height - margin.top - margin.bottom
  
  
  const xScale = scaleLinear()
								.domain([0, max(data, xValue)])
   							.range([0, innerWidth])
  
  const yScale = scaleBand()
  		.domain(data.map(yValue))
  		.range([0, innerHeight])
  		.padding(0.1)
  
  const xAxisFormat = num => format('.3s')(num).replace('G','B')
  
  const yAxis = axisLeft(yScale)
  				
  const xAxis = axisBottom(xScale).tickFormat(xAxisFormat)
  							.tickSize(-innerHeight)
  
  const g = svg.append('g')
  						 .attr('transform', `translate(${margin.left},${margin.top})`)
  
  g.append('g').call(yAxis)
    						.selectAll('.domain, .tick line').remove()
  							
 const xAxisG = g.append('g').call(xAxis)
  							.attr('transform', `translate(0,${innerHeight})`)
 
 							xAxisG
  							.select('.domain').remove()
  
  			xAxisG.append('text')
          .attr('class','axisX')
          .text('Population').attr('fill','black')
  								.attr('x',innerWidth/2).attr('y','60')
  
  g.selectAll('rect').data(data)
  		.enter().append('rect')
  	.attr('y',d => yScale(yValue(d)))
  	.attr('width', d => xScale(xValue(d)))
  	.attr('height', yScale.bandwidth())
  
  g.append('text')
           .text('Top Country By Population')
  					.attr('y','-10')

}
  

csv('data.csv').then(data => {
  data.forEach(d => {
  d.population = +d.population * 1000
  })
  render(data)
})







